<?php
/**
 * @copyright Copyright (c) 2016 www.magebuzz.com
 */

namespace Magebuzz\Socialshare\Block;

use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\Pricing\Helper\Data as PricingHelper;
use Magento\Framework\Registry;
use Magento\Framework\View\Element\Template\Context;
use Magento\Store\Model\ScopeInterface;
use Magento\Catalog\Helper\Image;

class Socialshare extends \Magento\Framework\View\Element\Template
{
    public $_coreRegistry;
    public $_scopeConfig;
    public $_product;
    public $_priceHelper;
    protected $imageHelper;

    public function __construct(
        Context $context,
        Registry $coreRegistry,
        PricingHelper $PricingHelper,
        Image $imageHelper,
        array $data = array()
    )
    {
        parent::__construct($context, $data);
        $this->_scopeConfig = $context->getScopeConfig();
        $this->_priceHelper = $PricingHelper;
        $this->_coreRegistry = $coreRegistry;
        $this->_product = $this->_coreRegistry->registry('current_product');
        $this->imageHelper = $imageHelper;
    }

    public function getShareDescription()
    {
        $_product = $this->_product;

        $productName = $_product->getName();
        $productPrice = strip_tags($this->_priceHelper->currency(round($_product->getPrice(), 2)));
        $limit = $this->_scopeConfig->getValue('socialshare/whatsapp/description_limit', ScopeInterface::SCOPE_STORE);
        $productShortdesc = substr(strip_tags($_product->getDescription()), 0, $limit);
        $productsData = $this->_scopeConfig->getValue('socialshare/whatsapp/share_desc', ScopeInterface::SCOPE_STORE);
        $productsData = nl2br($productsData);
        $productsData = str_replace(array("[product-title]", "[product-price]", "[product-description]"), array($productName, $productPrice, $productShortdesc), $productsData);
        $productsData = str_replace(array("<br>", "<br/>", "<br />"), array("%0a", "%0a", "%0a"), $productsData);

        return $productsData;
    }

    public function getFacebookButton()
    {
        $facebookID = $this->_scopeConfig->getValue('socialshare/facebook/fb_id', ScopeInterface::SCOPE_STORE);
        $displayLike = $this->_scopeConfig->getValue('socialshare/facebook/display_onlylike', ScopeInterface::SCOPE_STORE);
        $displayFbCount = $this->_scopeConfig->getValue('socialshare/facebook/display_facebook_count', ScopeInterface::SCOPE_STORE);
        $facebookID = ($facebookID != "") ? $facebookID : '1082368948492595';
        $like_button = ($displayLike == 1) ? false : true;
        $count_button = ($displayFbCount == 1) ? 'button_count' : 'button';
        $productUrl = urlencode($this->_product->getProductUrl());

        return '
        <a onclick=\'window.open("https://www.facebook.com/dialog/feed?app_id='.$facebookID.'&display=popup&link=' . $productUrl . '","fb_sharer","toolbar=0,status=0,width=626,height=436")\'>
           <span class="icon-facebook"></span>
        </a>

        ';
    }

    public function getTwitterButton()
    {

        $productName = $this->_product->getName();
        $productUrl = urlencode($this->_product->getProductUrl());

        return '
        <a onclick=\'window.open("http://twitter.com/home?status='. $productName . " " . $productUrl . '", "tw_sharer", "toolbar=0,status=0,width=626,height=436")\'>
        <span class="icon-twitter"></span>
        </a>
        ';

    }

    public function getPinItButton()
    {
        $image = 'product_base_image';
        $productName = $this->_product->getName();
        $productUrl = urlencode($this->_product->getProductUrl());
        $productImage = urlencode($this->imageHelper->init($this->_product, $image)->getUrl());

        return '
        <a onclick=\'window.open("http://pinterest.com/pin/create/button/?url='. $productUrl . "&description=" . $productName . '&media='.$productImage.'", "pinterest-share-dialog", "toolbar=0,status=0,width=626,height=436")\'>
        <span class="icon-pinterest"></span>
        </a>
        ';


    }

    public function getGooglePlusButton()
    {
        $count_button = $this->_scopeConfig->getValue('socialshare/googleplus/display_google_count', ScopeInterface::SCOPE_STORE);
        $count_button = ($count_button == 1) ? 'bubble' : 'none';

        return '<div class="google_button social-button">
        <div class="g-plusone" data-size="medium"  data-annotation="' . $count_button . '"></div>
        </div>
        <script src="https://apis.google.com/js/platform.js" async defer></script>';
    }

    public function getWhatsappButton()
    {
        $productName = $this->_product->getName();
        $productUrl = urlencode($this->_product->getProductUrl());

        return '<a class="hidden-xs hidden-sm" data-action="share/whatsapp/share" onclick=\'window.open("https://web.whatsapp.com/send?text='. $productName . " " . $productUrl . '", "whatsapp-dialog", "toolbar=0,status=0,width=626,height=436")\'>
            <span class="icon-whatsapp"></span>
        </a>
        <a class="hidden-md hidden-lg" href=\'whatsapp://send?text='. $productName . " " . $productUrl . '\' data-action="share/whatsapp/share">
            <span class="icon-whatsapp"></span>
        </a>
        ';
    }

    public function getTelegramButton()
    {
        $productName = $this->_product->getName();
        $productUrl = urlencode($this->_product->getProductUrl());

        return '
        <a onclick=\'window.open("https://t.me/share/url?url='. $productUrl . '", "telegram-dialog", "toolbar=0,status=0,width=626,height=436")\'>
            <span class="icon-telegram"></span>
        </a>
        ';
    }
}
